@@ -15,25 +15,26 @@ Versioning semantics:
 
 __intname__ = "ofunctions.random"
 __author__ = "Orsiris de Jong"
-__copyright__ = "Copyright (C) 2014-2021 Orsiris de Jong"
+__copyright__ = "Copyright (C) 2014-2022 Orsiris de Jong"
 __description__ = "Simple random string generator including password generator"
 __licence__ = "BSD 3 Clause"
-__version__ = "0.1.1"
-__build__ = "2020102801"
+__version__ = "0.2.0"
+__build__ = "2022041401"
+__compat__ = "python2.7+"
 
 
 import string
 import random
 
 
-def random_string(
-    size: int = 8, chars: list = string.ascii_letters + string.digits
-) -> str:
+def random_string(size=8, chars=string.ascii_letters + string.digits):
+    # type: (int, list) -> str
     """
     Simple password generator function
     """
     return "".join(random.choice(chars) for _ in range(size))
 
 
-def pw_gen(size: int = 16, chars: list = string.ascii_letters + string.digits) -> str:
+def pw_gen(size=16, chars=string.ascii_letters + string.digits):
+    # type: (int, list) -> str
     return random_string(size, chars)
